'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
/**
 * Routes middlewares
 * Use it like this:
 *
 * 'GET /posts': {
 *    middlewares: [setPaginationHeaders],
 *  },
 */

/**
 * Add headers for the pagination.
 * Handle query params like: ?page=2&perpage=10
 *
 * @param  {Object} data Selected data
 */
var setPaginationHeaders = exports.setPaginationHeaders = function setPaginationHeaders(data) {
  return function (req, res, next) {
    var page = req.query.page || 1;
    var perPage = req.query.perPage || 10;
    var pageCount = Math.ceil(data.length / perPage);
    var totalCount = data.length;
    var slicedData = data.slice((page - 1) * perPage, page * perPage);

    var headers = {
      'x-page': page,
      'x-per-page': perPage,
      'x-page-count': pageCount,
      'x-total-count': totalCount
    };

    res.data = slicedData;
    res.set(headers);

    next();
  };
};